@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Base routines
 #
-# $Id: LONCAPA.pm,v 1.34 2013/02/08 14:49:51 raeburn Exp $
+# $Id: LONCAPA.pm,v 1.35.2.2 2019/08/25 22:29:29 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -138,6 +138,13 @@ sub tempdir {
     return $result;
 }
 
+# Return the default engine to use to render content of <m></m> tags unless
+# a domain, course, or user specific value exists. 
+
+sub texengine {
+    return 'tth';
+}
+
 # Return the Linux distro where this LON-CAPA instance is running
 
 sub distro {
@@ -149,6 +156,13 @@ sub distro {
     return $distro;
 }
 
+# Return the default password length. Can be overridden in a domain
+# by specifying a larger value (integer) in the domain configuration.
+
+sub passwd_min {
+    return 7;
+}
+
 #----------------------------------------------------------------------
 #
 #  some of these subs need a bit of documentation
