@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Authorization Handler for webDAV access to Authoring Space. 
 #
-# $Id: lonwebdavacc.pm,v 1.5 2015/05/29 20:00:49 raeburn Exp $
+# $Id: lonwebdavacc.pm,v 1.7 2020/12/18 15:23:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -157,7 +157,7 @@ sub handler {
         }
     } else {
         if (($env{"user.role.ca./$adom/$aname"}) ||
-            (env{"user.role.aa./$adom/$aname"})) {
+            ($env{"user.role.aa./$adom/$aname"})) {
             $allowed = 1;
         }
     }
@@ -234,8 +234,9 @@ sub sso_login {
         if (&Apache::lonnet::usertools_access($uname,$udom,'webdav')) {
             my ($webdav) =
                 ($r->uri =~ m{^(/webdav/$match_domain/$match_username/)});
+            my $ip = &Apache::lonnet::get_requestor_ip();
             &Apache::lonnet::log($udom,$uname,$uhome,
-                                 "SSO log-in to $webdav from $ENV{'REMOTE_ADDR'}");
+                                 "SSO log-in to $webdav from $ip");
             my $cookie = "lonDAV=$handle; path=/webdav/; secure; HttpOnly;";
             $r->header_out('Set-cookie' => $cookie);
             $r->send_http_header;
