@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Authentication Handler for webDAV access to Authoring Space.
 #
-# $Id: lonwebdavauth.pm,v 1.7 2017/01/30 00:16:31 raeburn Exp $
+# $Id: lonwebdavauth.pm,v 1.8 2020/12/18 15:23:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -298,7 +298,7 @@ sub init_webdav_env {
                                                   \%userenv,\%domdef,\%is_adv);
             @env{keys(%disk_env)} = @disk_env{keys(%disk_env)};
             untie(%disk_env);
-            my $ip = $r->get_remote_host();
+            my $ip = &Apache::lonnet::get_requestor_ip($r);
             &Apache::lonnet::log($udom,$uname,$uhome,
                                  "Login webdav/$author $ip");
         }
