@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Cookie Based Access Handler
 #
-# $Id: publiccheck.pm,v 1.24.2.2 2021/01/04 03:53:20 raeburn Exp $
+# $Id: publiccheck.pm,v 1.24.2.3 2022/01/05 03:56:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -92,7 +92,7 @@ sub process_public {
         my $cookie=&Apache::lonauth::success($r,'public','public','public');
         my $lonidsdir=$r->dir_config('lonIDsDir');
         &Apache::lonnet::transfer_profile_to_env($lonidsdir,$cookie);
-	$r->err_header_out('Set-cookie',"lonID=$cookie; path=/; HttpOnly");
+	$r->err_header_out('Set-cookie',"lonPubID=$cookie; path=/; HttpOnly");
     }
     &Apache::lonacc::get_posted_cgi($r);
     $env{'request.state'} = "published";
