@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Firewall configuration to allow internal LON-CAPA communication between servers   
 #
-# $Id: Firewall.pm,v 1.25 2021/12/21 16:42:15 raeburn Exp $
+# $Id: Firewall.pm,v 1.27 2024/06/13 17:18:38 raeburn Exp $
 #
 # The LearningOnline Network with CAPA
 #
@@ -332,7 +332,7 @@ sub firewall_is_port_open {
         while(<PIPE>) {
             if ($port eq $lond_port) {
                 if (ref($iphost) eq 'HASH') {
-                    if (/^ACCEPT\s+tcp\s+\-{2}\s+(\S+)\s+\S+\s+tcp\s+dpt\:\Q$port\E/) {
+                    if (/^ACCEPT\s+(?:tcp|6)\s+\-{2}\s+(\S+)\s+\S+\s+tcp\s+dpt\:\Q$port\E/) {
                         my $ip = $1;
                         if ($iphost->{$ip}) {
                             $count ++;
@@ -365,6 +365,18 @@ sub firewall_is_active {
             }
             close(PIPE);
         }
+        unless ($status) {
+            if (open(PIPE,'nft list tables |')) {
+                while(<PIPE>) {
+                    chomp();
+                    if (/filter$/) {
+                        $status = 1;
+                        last;
+                    }   
+                }           
+                close(PIPE);      
+            }           
+        }
     }
     unless ($status) {
         $status = &uses_firewalld();
@@ -458,7 +470,7 @@ sub firewall_close_port {
                         while (<PIPE>) {
                             chomp();
                             next unless (/dpt:\Q$port\E/);
-                            if (/^ACCEPT\s+tcp\s+\-{2}\s+(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\s+/) {
+                            if (/^ACCEPT\s+(?:tcp|6)\s+\-{2}\s+(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\s+/) {
                                 my $ip = $1;
                                 my $keepopen = 0;
                                 if (ref($iphost) eq 'HASH') {
@@ -613,7 +625,7 @@ sub firewall_close_anywhere {
         while (<PIPE>) {
             next unless (/dpt:\Q$port\E/);
             chomp();
-            if (/^(\d+)\s+ACCEPT\s+tcp\s+\-{2}\s+0\.0\.0\.0\/0\s+0\.0\.0\.0\/0/) {
+            if (/^(\d+)\s+ACCEPT\s+(?:tcp|6)\s+\-{2}\s+0\.0\.0\.0\/0\s+0\.0\.0\.0\/0/) {
                 my $firewall_command = "$iptables -D $fw_chain $1";
                 system($firewall_command);
                 my $return_status = $?>>8;
