@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.333.2.12 2021/12/12 21:21:44 raeburn Exp $
+# $Id: inputtags.pm,v 1.333.2.15 2024/07/01 23:09:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -450,6 +450,7 @@ sub start_textline {
 		if ($addchars) {
 		    $result.=&addchars('HWVAL_'.$id,$addchars);
 		}
+                my $numrespclass;
 		my $readonly=&Apache::lonxml::get_param('readonly',$parstack,
 							$safeeval);
 		if (lc($readonly) eq 'yes' 
@@ -457,6 +458,10 @@ sub start_textline {
 		    $readonly=' readonly="readonly" ';
 		} else {
 		    $readonly='';
+                    if (($Apache::inputtags::status['-1'] eq 'CAN_ANSWER') &&
+                        ($tagstack->[-2] eq 'numericalresponse')) {
+                        $numrespclass = ' LC_numresponse_text';
+                    }
 		}
 		my $name = 'HWVAL_'.$id;
                 my $itemid = 'HWVAL_'.$partid.'_'.$id;
@@ -469,12 +474,14 @@ sub start_textline {
 		     . ' type="text" '.$readonly.' name="'. $name . '"'
 		     . ' id="' . $input_tag_id . '"'
 		     . ' value="'.  $oldresponse.'"'
-		     . ' class="LC_textline spellchecked"  size="'.$size.'"'.$maxlength.' />';
+		     . ' class="LC_textline spellchecked'.$numrespclass.'" size="'.$size.'"'.$maxlength.' />';
 
 		$result .= &spellcheck_onblur($itemid, $spellcheck);
                 if (($Apache::inputtags::status['-1'] eq 'CAN_ANSWER') &&
-                    (($tagstack->[-2] eq 'formularesponse') || ($tagstack->[-2] eq 'mathresponse')) &&
-                    (&Apache::lonnet::EXT('resource.'.$partid.'_'.$id.'.turnoffeditor') ne 'yes')) {
+                    (((($tagstack->[-2] eq 'formularesponse') || ($tagstack->[-2] eq 'mathresponse')) &&
+                      (&Apache::lonnet::EXT('resource.'.$partid.'_'.$id.'.turnoffeditor') ne 'yes')) ||
+                     (($tagstack->[-2] eq 'customresponse') &&
+                       (&Apache::lonnet::EXT('resource.'.$partid.'_'.$id.'.turnoffeditor') eq 'no')))) {
                     $result.=&edit_mathresponse_button($input_tag_id);
                 }
 	    }
@@ -656,8 +663,13 @@ sub file_selector {
     $result .= &Apache::lonhtmlcommon::row_title($addfiles);
     my $constraints;
     if ($uploadedfiletypes ne '*') {
+        my $showtypes = $uploadedfiletypes;
+        if ($showtypes =~ /,/) {
+            my $conjunc = &mt('or');
+            $showtypes =~ s/,([^,]+)$/ $conjunc $1/;
+        }
 	$constraints =
-	    &mt('Allowed filetypes: [_1]','<b>'.$uploadedfiletypes.'</b>').'<br />';
+	    &mt('Allowed filetypes: [_1]','<b>'.$showtypes.'</b>').'<br />';
     }
     if ($maxfilesize) {
         $constraints .= &mt('Combined size of all files not to exceed: [_1] MB.',
