@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Interface routines to R CAS
 #
-# $Id: lonr.pm,v 1.11 2014/11/19 21:14:47 raeburn Exp $
+# $Id: lonr.pm,v 1.12 2024/06/21 23:42:49 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -243,9 +243,9 @@ sub blacklisted {
 }
 
 sub r_allowed_libraries {
-   return ('alr3','boot','car','class','cluster','datasets','Hmisc','KernSmooth','leaps','lmtest',
-           'MASS','methods','mgcv','nlme','nnet','qAnalyst','quadprog','rpart','SuppDists','spatial',
-           'splines','stats','stats4','survival','tseries','zoo');
+   return ('alr3','boot','car','class','cluster','datasets','FactoMineR','Hmisc','KernSmooth','leaps',
+           'lmtest','MASS','mdatools','methods','mgcv','nlme','nnet','qAnalyst','quadprog','rpart', 
+           'SuppDists','spatial','splines','stats','stats4','survival','tseries','zoo');
 }
 
 sub r_is_allowed_library {
