@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Full matching style response
 #
-# $Id: matchresponse.pm,v 1.92 2015/01/19 15:35:53 goltermann Exp $
+# $Id: matchresponse.pm,v 1.92.2.1 2018/06/08 11:57:57 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -685,7 +685,7 @@ sub displayfoils {
 	    my $last_letter=$name_letter_map{$lastopt};
 	    my $optionlist = '';
 	    if ($target ne 'tex') {
-		$optionlist="<option></option>\n";
+		$optionlist="<option value=\"\"></option>\n";
 	    } else {
 		if ($Apache::lonhomework::type ne 'exam') {
                     if($env{'form.pdfFormFields'} eq 'yes'
@@ -702,7 +702,7 @@ sub displayfoils {
 	    foreach $option (@used_letters) {
 		if ($option eq $last_letter) {
 		    if ($target ne 'tex') {
-                        $optionlist.="<option selected=\"selected\">$option</option>\n";
+                        $optionlist.="<option value=\"$option\" selected=\"selected\">$option</option>\n";
                     } elsif ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
                              && $Apache::inputtags::status['-1'] eq 'CAN_ANSWER'
                              && $Apache::lonhomework::type ne 'exam') {
@@ -710,7 +710,7 @@ sub displayfoils {
                     }
 		} else {
 		    if ($target ne 'tex') {
-                        $optionlist.="<option>$option</option>\n";
+                        $optionlist.="<option value=\"$option\">$option</option>\n";
                     } elsif ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
                              && $Apache::inputtags::status['-1'] eq 'CAN_ANSWER'
                              && $Apache::lonhomework::type ne 'exam') {
