@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.244.2.3 2021/01/12 15:57:18 raeburn Exp $
+# $Id: response.pm,v 1.244.2.4 2024/07/02 00:40:42 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -766,7 +766,8 @@ sub start_responseparam {
 	}
     } elsif ($target eq 'grade' || $target eq 'answer' || $target eq 'web' ||
 	     $target eq 'tex' || $target eq 'analyze' ) {
-	if ($env{'request.state'} eq 'construct') {
+	if (($env{'request.state'} eq 'construct') ||
+	    ($env{'request.noversionuri'} =~ m{^\Q/res/adm/includes/templates/\E[^/]+\.problem$})) {
 	    my $name   =&Apache::lonxml::get_param('name',$parstack,$safeeval);
 	    my $default=&Apache::lonxml::get_param('default',$parstack,
 						     $safeeval);
@@ -797,7 +798,10 @@ sub reset_params {
 sub setup_params {
     my ($tag,$safeeval) = @_;
 
-    if ($env{'request.state'} eq 'construct') { return; }
+    if (($env{'request.state'} eq 'construct') ||
+        ($env{'request.noversionuri'} =~ m{^\Q/res/adm/includes/templates/\E[^/]+\.problem$})) {
+        return;
+    }
     my %paramlist=();
     foreach my $key (keys(%Apache::lonnet::packagetab)) {
 	if ($key =~ /^\Q$tag\E/) {
