@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # This will take annotations and then plug them into a page.
 #
-# $Id: admannotations.pm,v 1.36 2018/12/29 22:31:16 raeburn Exp $
+# $Id: admannotations.pm,v 1.37 2021/12/24 00:48:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -175,6 +175,27 @@ $end_page
 END_HTML2
 }
 
+sub block_check {
+    my ($clientip) = @_;
+    my ($blocked,$blocktext) =
+        &Apache::loncommon::blocking_status('annotate',$clientip);
+    if ($blocked) {
+        my %lt = &Apache::lonlocal::texthash(
+                                              'close' => 'Close',
+                                            );
+        my $start_page =
+            &Apache::loncommon::start_page('Annotations',undef,
+                                           {'only_body'   => 1,});
+        my $end_page = '<form name="annotInfo" method="post" action="">'."\n".
+                       '<input type="button" id="close" name="close" value="'.$lt{'close'}.'"'.
+                       ' onclick="javascript:window.close();" />'."\n".
+                       '</form>'."\n".
+                       &Apache::loncommon::end_page();
+        return ($blocked,$start_page.$blocktext.$end_page);
+    } else {
+        return ();
+    }
+}
 
 # ---------------------------------------------------------------Main Handler
 
@@ -185,6 +206,15 @@ sub handler {
     $r->send_http_header;
     return OK if $r->header_only;
 
+    my $clientip = &Apache::lonnet::get_requestor_ip($r);
+    if ($clientip ne '') {
+        my ($blocked,$output) = &block_check($clientip);
+        if ($blocked) {
+            $r->print($output);
+            return OK;
+        }
+    }
+
     my $page;
 
     my ($symb_old,$symb_old_enc) = &Apache::loncommon::clean_symb($env{'form.symbold'},1);
