@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Bulletin Board Handler
 #
-# $Id: lonbulletin.pm,v 1.63 2011/05/02 18:32:30 raeburn Exp $
+# $Id: lonbulletin.pm,v 1.69 2020/09/08 23:54:40 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,9 +33,12 @@ use Apache::Constants qw(:common);
 use Apache::loncommon;
 use Apache::lonnet;
 use Apache::lontexconvert;
-use Apache::lonfeedback;
+use Apache::lonfeedback; 
+use Apache::lonhtmlgateway;
 use Apache::lonlocal;
 use Apache::lonhtmlcommon;
+use Apache::longroup;
+use Apache::lonnavmaps;
 use HTML::Entities();
 use LONCAPA;
 
@@ -78,7 +81,7 @@ sub handler {
 
 # ------------------------------------------------------------ Get Query String
     &Apache::loncommon::get_unprocessed_cgi
-                ($ENV{'QUERY_STRING'},['forcestudent','forceedit','register',
+                ($ENV{'QUERY_STRING'},['forceedit','register','todocs',
                                        'origpage','group','ref']);
 # ----------------------------------------------------- Force menu registration
     my %addentries;
@@ -86,11 +89,11 @@ sub handler {
         $addentries{'onload'} = "document.location='#newpost';";
     }
 # --------------------------------------------------------------- Force Student
-    my $forcestudent='';
-    if ($env{'form.forcestudent'}) { $forcestudent='student'; }
-
-    my $forceedit='';
-    if ($env{'form.forceedit'}) { $forceedit='edit'; }
+    my ($forceedit,$forcestudent);
+    $forceedit = $env{'form.forceedit'};
+    if (!$forceedit) {
+        $forcestudent=1;
+    }
     my $refarg = '';
     if (exists($env{'form.ref'})) { $refarg = 'ref='.$env{'form.ref'}; }
 
@@ -125,21 +128,17 @@ sub handler {
 
 # --------------------------------------- There is such a user, get environment
     if ($target ne 'tex') {
-        my $course_or_group;
+        my ($course_or_group,$brcrum);
         if($group eq '') {
             $course_or_group="Course";
         } else {
             $course_or_group="Group";
         }
-        my $start_page =
-            &Apache::loncommon::start_page("$course_or_group Discussion Board",undef,
-                                           {'function'       => $forcestudent,
-                                            'add_entries'    => \%addentries,
-                                            'domain'         => $dom,
-                                            'force_register' =>
-                                                $env{'form.register'}});
-        $r->print($start_page);
+        my $registered;
         if ($group ne '' && $env{'form.group'} eq $group) {
+            unless ($env{'form.ref'} eq 'grouplist') {
+                $registered = $env{'form.register'}; 
+            }
             my $gpterm =  &Apache::loncommon::group_term();
             my $ucgpterm = $gpterm;
             $ucgpterm =~ s/^(\w)/uc($1)/e;
@@ -149,10 +148,28 @@ sub handler {
             if ((ref($groupboards) eq 'ARRAY') && (@{$groupboards} > 0)) {
                 $boardtitle = $$boards{$$groupboards[0]}{'title'};
             }
-            $boardurl .= '?register=1&amp;group='.$group;
-            $r->print(&groupboard_breadcrumbs($dom,$crs,$group,$refarg,$gpterm,
-                                $ucgpterm,$grp_desc,$boardurl,$boardtitle));
+            $boardurl .= '?group='.$group;
+            if ($registered) {
+                $boardurl .= '&amp;register='.$env{'form.register'};
+            } else {
+                $brcrum = 
+                    &groupboard_breadcrumbs($dom,$crs,$group,$refarg,$gpterm,
+                                            $ucgpterm,$grp_desc,$boardurl,
+                                            $boardtitle);
+            }
+        } else {
+            $registered = $env{'form.register'};
+            $brcrum = [];
         }
+        my $start_page =
+            &Apache::loncommon::start_page("$course_or_group Discussion Board",undef,
+                                           {'add_entries'    => \%addentries,
+                                            'domain'         => $dom,
+                                            'bread_crumbs'   => $brcrum, 
+                                            'group'          => $group,
+                                            'force_register' => $registered}
+                                          );
+        $r->print($start_page);
     }
     my ($allowed);
     if ($group ne '') {
@@ -173,43 +190,8 @@ sub handler {
         $allowed=&Apache::lonnet::allowed('mdc',$env{'request.course.id'});
     }
 
-    my $privileged=$allowed;
-    if (($syllabus{'uploaded.lastmodified'}) && (!$forceedit)) {
-        $forcestudent='student';
-    }
     if ($forcestudent or $target eq 'tex') { $allowed=0; }
 
-    if ($allowed) {
-        my $query_str = 'forcestudent=1';
-        if (($group ne '') && ($env{'form.group'} eq $group)) {
-            $query_str.='&amp;group='.$group.'&amp;'.$refarg;
-        }
-        if ($env{'form.register'}) {
-            $query_str .= '&amp;register='.$env{'form.register'};
-        }
-        #Function Box for Edit Mode.
-        my $functionbox = &Apache::lonhtmlcommon::start_funclist();
-        $functionbox .=  &Apache::lonhtmlcommon::add_item_funclist(
-                             '<a href="'.$r->uri.'?'.$query_str.'">'.&mt('Show Student View').'</a>'.
-                              &Apache::loncommon::help_open_topic('Uploaded_Templates_PublicView'));
-        $functionbox.=&Apache::lonhtmlcommon::end_funclist();
-        $r->print(&Apache::loncommon::head_subbox($functionbox).&Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes',&mt('Help with filling in text boxes')));
-    } elsif ($privileged and $target ne 'tex') {
-        my $query_str = 'forceedit=edit';
-        if (($group ne '') && ($env{'form.group'} eq $group)) {
-            $query_str.='&amp;group='.$group.'&amp;'.$refarg;
-        }
-        if ($env{'form.register'}) {
-            $query_str .= '&amp;register='.$env{'form.register'};
-        }
-        #Functionbox for Student view.
-        my $functionbox = &Apache::lonhtmlcommon::start_funclist();
-        $functionbox .=  &Apache::lonhtmlcommon::add_item_funclist(
-                             "<a href='".$r->uri.'?'.$query_str."'>".&mt('Edit')."</a>");
-        $functionbox.=&Apache::lonhtmlcommon::end_funclist();
-        $r->print(&Apache::loncommon::head_subbox($functionbox));
-    }
-
     if (($env{'form.uploaddoc.filename'}) &&
         ($env{'form.storeupl'}) && ($allowed)) {
         if ($env{'form.uploaddoc.filename'}=~/\.(gif|jpg|png|jpeg)$/i) {
@@ -232,8 +214,9 @@ sub handler {
     if (($allowed) && ($env{'form.storesyl'})) {
         foreach my $syl_field (keys(%syllabusfields)) {
             my $field=$env{'form.'.$syl_field};
-            $field=~s/\s+$//s;
-            $field=&Apache::lonfeedback::clear_out_html($field,1);
+            chomp($field);
+            my $gateway = Apache::lonhtmlgateway->new();
+            $field = $gateway->process_incoming_html($field,1);
             $syllabus{$syl_field}=$field;
         }
         $syllabus{'uploaded.lastmodified'}=time;
@@ -272,10 +255,9 @@ sub handler {
             $r->print($message);
             $r->print("<br /><br />");
             $r->print(
-                '<input type="hidden" name="forceedit" value="edit" />'.
+                '<input type="hidden" name="forceedit" value="'.$env{'form.forceedit'}.'" />'.
                 '<input type="file" name="uploaddoc" size="50" />'.
-                '<input type="submit" name="storeupl" value="'.&mt('Upload').'" />'.
-                '<input type="hidden" name="forceedit" value="edit" />');
+                '<input type="submit" name="storeupl" value="'.&mt('Upload').'" />');
             &Apache::lontemplate::print_end_template($r);
         }
         #Image in Student view.
@@ -327,25 +309,40 @@ sub groupboard_breadcrumbs {
     my ($cdom,$cnum,$group,$refarg,$gpterm,$ucgpterm,$description,$boardurl,
         $boardtitle)= @_;
     &Apache::lonhtmlcommon::clear_breadcrumbs();
+    my $brcrum = [];
     if ($refarg ne '') {
-        &Apache::lonhtmlcommon::add_breadcrumb
-            ({href=>"/adm/coursegroups",
-              text=>"Groups",
-              title=>"View course groups"});
+        push(@{$brcrum},
+              {href=>"/adm/coursegroups",
+               text=>"Groups",
+               title=>"View course groups"});
     }
-    &Apache::lonhtmlcommon::add_breadcrumb
-        ({href=>"/adm/$cdom/$cnum/$group/smppg?$refarg",
-          text=>"$ucgpterm: $description",
-          title=>"Go to group's home page"},
-         {href=>"/adm/groupboards?group=$group&amp;$refarg",
-          text=>"Discussion Boards",
-          title=>"Display group discussion boards"},
-         {href=>"$boardurl",
-          text=>"$boardtitle",
-          title=>"$boardtitle"},
+    my $view_permission =
+          &Apache::lonnet::allowed('vcg',$env{'request.course.id'}.($env{'request.course.sec'}?'/'.$env{'request.course.sec'}:''));
+    my $navmap=Apache::lonnavmaps::navmap->new();
+    my $grouppagelink = &Apache::longroup::get_group_link($cdom,$cnum,$group,$navmap,$view_permission,$refarg);
+    if ($grouppagelink) {
+        push(@{$brcrum},
+            {href=>$grouppagelink,
+             text=>&mt('Group').": $description",
+             title=>&mt("Go to group's home page"),
+             no_mt=>1,},
         );
-    my $output .= &Apache::lonhtmlcommon::breadcrumbs(&mt('[_1] discussion boards - [_2]',$gpterm,$description));
-    return $output;
+    } else {
+        push(@{$brcrum},
+            {text=>&mt('Group').": $description",
+             no_mt=>1,}
+        );
+    }
+    push(@{$brcrum},
+           {href=>"/adm/groupboards?group=$group&amp;$refarg",
+            text=>"Discussion Boards",
+            title=>"Display group discussion boards"},
+           {href=>"$boardurl",
+            text=>"$boardtitle",
+            title=>"$boardtitle",
+            no_mt=>1},
+        );
+    return $brcrum;
 }
 
 1;
