@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # routines for clone a course
 #
-# $Id: lonclonecourse.pm,v 1.12 2016/01/21 00:12:38 raeburn Exp $
+# $Id: lonclonecourse.pm,v 1.13.2.1 2020/07/24 18:06:24 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -107,7 +107,7 @@ sub rewritefile {
 
 sub copyfile {
     my ($origcrsid,$newcrsid,$which)=@_;
-    unless ($which=~/\.sequence$/) {
+    unless ($which=~/\.(page|sequence)$/) {
 	return &writefile($newcrsid,$which,
 		      &readfile($origcrsid,$which));
     } else {
@@ -220,8 +220,14 @@ sub copyresourcedb {
                         if (($origtz eq 'local') && (!$ENV{TZ})) {
                             $ENV{TZ} = $dt->time_zone()->name();
                         }
-                        $dt->add(days => int($date_shift));
-                        $newdata{$thiskey} = $dt->epoch();
+                        eval {
+                            $dt->add(days => int($date_shift));
+                        };
+                        if ($@) {
+                            $newdata{$thiskey} = $newdata{$thiskey}+$delta+(60*60);
+                        } else {
+                            $newdata{$thiskey} = $dt->epoch();
+                        }
                     } else {
                         $newdata{$thiskey} = $newdata{$thiskey}+$delta;
                     }
