@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to set domain-wide configuration settings
 #
-# $Id: lonconfigsettings.pm,v 1.21.4.13 2021/12/28 02:32:31 raeburn Exp $
+# $Id: lonconfigsettings.pm,v 1.21.4.17 2024/07/14 23:48:58 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -239,13 +239,21 @@ $jscript
                 $additem = {'add_entries' => \%loaditems,};
             }
         } elsif ($context eq 'course') {
+            my $onload;
             if (grep(/^courseinfo$/,@actions)) {
                 if (@code_order) {
-                    $additem = {
-                                   add_entries => {'onload' => "courseSet('','load');toggleCloners(document.display.cloners_instcode);"},
-                               };
+                    $onload = "courseSet('','load');toggleCloners(document.display.cloners_instcode);";
                 }
             }
+            if (grep(/^grading$/,@actions)) {
+                $onload .= 'toggleGrading(document.display);toggleHiddenTotalsSec(document.display);';
+            }
+            if ($onload) {
+                my %loaditems = (
+                                  'onload' => $onload,
+                                );
+                $additem = {'add_entries' => \%loaditems,};
+            }
         }
     }
     $r->print(&Apache::loncommon::start_page($pagetitle,$js,$additem));
@@ -333,7 +341,7 @@ sub make_changes {
                 } else {
                     $changes{$item} = {};
                     $errors =
-                        &Apache::courseprefs::process_changes($dom,$item,$values,
+                        &Apache::courseprefs::process_changes($dom,$confname,$item,$values,
                                                               $prefs->{$item},$changes{$item},
                                                               $allitems,\%disallowed,$crstype);
                     if (keys(%{$changes{$item}}) > 0) {
@@ -376,8 +384,8 @@ sub make_changes {
     if ($context eq 'course') {
         $footer_text = 'Back to display/edit settings'; 
     }
-    &print_footer($r,$phase,'display',$footer_text,\@actions,$container,$parm_permission);
     $r->print('</p>');
+    &print_footer($r,$phase,'display',$footer_text,\@actions,$container,$parm_permission);
     return \%lastact;
 }
 
@@ -443,7 +451,7 @@ sub display_settings {
                                 $phase,$item,$prefs->{$item},$settings);
                     } else {
                         ($output{$item},$rowtotal{$item}) =
-                            &Apache::courseprefs::print_config_box($r,$dom,$phase,
+                            &Apache::courseprefs::print_config_box($r,$dom,$confname,$phase,
                                 $item,$prefs->{$item},$values,$allitems,$crstype,$parm_permission);
                     }
                     $rowsum += $rowtotal{$item};
