@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Navigate Maps Display Handler
 #
-# $Id: lonnavdisplay.pm,v 1.22.4.10 2021/03/04 01:38:00 raeburn Exp $
+# $Id: lonnavdisplay.pm,v 1.22.4.11 2024/07/02 02:17:56 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -65,7 +65,7 @@ sub real_handler {
 # ------------------------------------------------------------ Get query string
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['sort',
                                                                   'showOnlyHomework',
-                                                                  'postsymb','register']);
+                                                                  'postsymb']);
     # Check if course needs to be re-initialized
     my $loncaparev = $r->dir_config('lonVersion');
     my ($result,@reinit) = &Apache::loncommon::needs_coursereinit($loncaparev);
@@ -229,9 +229,6 @@ ENDCLOSE
         }
     } else {
         my $link = '/adm/navmaps?jumpToFirstHomework';
-        if ($env{'form.register'}) {
-            $link .= '&amp;register='.$env{'form.register'}; 
-        }
         unless ($notools) {
 	    &Apache::lonnavmaps::add_linkitem(\%toplinkitems,'firsthomework',
 					      'location.href="'.$link.'"',
@@ -252,9 +249,6 @@ ENDCLOSE
                             return $res->completable() || $res->is_map();
                         };
         my $link = '/adm/navmaps?sort='.$env{'form.sort'};
-        if ($env{'form.register'}) {
-            $link .= '&amp;register='.$env{'form.register'};
-        }
 	&Apache::lonnavmaps::add_linkitem(\%toplinkitems,'everything',
 					  'location.href="'.$link.'"',
 					  'Show everything');
@@ -264,9 +258,6 @@ ENDCLOSE
 	$resource_no_folder_link = 1;
     } else {
         my $link = '/adm/navmaps?sort='.$env{'form.sort'}.'&amp;showOnlyHomework=1';
-        if ($env{'form.register'}) {
-            $link .= '&amp;register='.$env{'form.register'};
-        }
         unless ($notools) {
 	    &Apache::lonnavmaps::add_linkitem(\%toplinkitems,'uncompleted',
 					      'location.href="'.$link.'"',
@@ -288,7 +279,6 @@ ENDCLOSE
                        <option value="duedate"'.$selected{'duedate'}.'>'.&mt('Due Date').'</option>
                        <option value="discussion"'.$selected{'discussion'}.'>'.&mt('Has New Discussion').'</option>
                     </select>
-                    <input type="hidden" name="register" value="'.$env{'form.register'}.'" />
                  </span>
                </form>');
     }
@@ -331,19 +321,12 @@ sub startpage {
     # Header
     my $course_type = &Apache::loncommon::course_type();
     my $title = $course_type . ' Contents';
-    my ($start_page,$args);
-    if ($env{'form.register'}) {
-        $args = {'force_register' => $env{'form.register'}};
-        $start_page = &Apache::loncommon::start_page($title,undef,$args);
-    } else {
-        my $brcrum = [{href => '/adm/navmaps',
-                       text => &mt($course_type . ' Contents'),
-                       no_mt => 1},
-                     ];
-        $args = {'bread_crumbs' => $brcrum};
-        $start_page = &Apache::loncommon::start_page($title,undef,$args);
-    }
-    $r->print($start_page.
+    my $brcrum = [{href => '/adm/navmaps',
+                   text => &mt($course_type . ' Contents'),
+                   no_mt => 1},
+                 ];
+    my $args = {'bread_crumbs' => $brcrum};
+    $r->print(&Apache::loncommon::start_page($title,undef,$args).
               '<script type="text/javascript">'."\n".
               '// <![CDATA['."\n".
               'window.focus();'."\n".
