@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Simple Page Editor
 #
-# $Id: lonsimplepage.pm,v 1.106 2020/09/09 18:37:00 raeburn Exp $
+# $Id: lonsimplepage.pm,v 1.107 2021/11/30 15:55:37 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -207,8 +207,9 @@ sub handler {
             }
             return OK;
         }
+        my $clientip = &Apache::lonnet::get_requestor_ip($r);
         my ($blocked,$blocktext) =
-             &Apache::loncommon::blocking_status('groups');
+             &Apache::loncommon::blocking_status('groups',$clientip);
         if ($blocked) {
             $r->print($blocktext);
             $r->print(&Apache::loncommon::end_page());
