@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentassessment.pm,v 1.169.2.7 2019/03/20 03:43:47 raeburn Exp $
+# $Id: lonstudentassessment.pm,v 1.169.2.8 2024/07/02 14:19:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -741,7 +741,10 @@ NEW_WINDOW_CHECKBOX
                             length($title)
                             )).$padding;
     }
-    $total_sum_width = length($total_count)+1;
+    $total_sum_width = length($total_count);
+    if ($total_sum_width < 6) {
+        $total_sum_width = 6;
+    }
     $Str .= "    total</pre>\n";
     $Str .= "<pre>";
 
@@ -935,6 +938,7 @@ sub html_outputstudent {
         $score = sprintf("%.2f",$score);
         $score = (' 'x(6-length($score))).$score;
     }
+    $max = sprintf("%.2f",$max);
     $Str .= ' '.' 'x($total_sum_width-length($score)).$score.' / '.$max;
     $Str .= " \n";
     #
