@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.184 2020/02/02 20:12:31 raeburn Exp $
+# $Id: lonplot.pm,v 1.185 2022/09/21 11:49:48 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -40,6 +40,7 @@ use Apache::lonxml;
 use Apache::edit;
 use Apache::lonnet;
 use Apache::lonlocal;
+use Time::HiRes qw(gettimeofday);
 use LONCAPA;
 
 use vars qw/$weboutputformat $version $colorprefix/;
@@ -728,8 +729,9 @@ sub end_gnuplot {
 	&check_inputs(); # Make sure we have all the data we need
 	##
 	## Determine filename
+        my ($seconds, $microseconds) = gettimeofday;
 	my $filename = $env{'user.name'}.'_'.$env{'user.domain'}.
-	    '_'.time.'_'.$$.$randnumber.'_plot';
+	    '_'.$seconds.'_'.$microseconds.'_'.$$.$randnumber.'_plot';
 	## Write the plot description to the file
 	&write_gnuplot_file($tmpdir,$filename,$target);
 	$filename = &escape($filename);
