@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 #  Generating TeX tables.
 #
-# $Id: lontable.pm,v 1.21 2011/11/30 18:01:33 raeburn Exp $
+# $Id: lontable.pm,v 1.22 2014/12/15 00:52:40 raeburn Exp $
 # 
 #
 # Copyright Michigan State University Board of Trustees
@@ -276,7 +276,7 @@ sub new {
 
     };
 
-    foreach my $key (keys %$configuration) {
+    foreach my $key (keys(%$configuration)) {
 	$self->{$key} = $$configuration{$key};
     }
 
@@ -500,7 +500,7 @@ sub start_row {
     # Override the defaults if the config hash is present:
 
     if (defined($config)) {
-	foreach my $key  (keys %$config) {
+	foreach my $key  (keys(%$config)) {
 	    $row_hash->{$key} = $config->{$key};
 	}
     }
@@ -583,7 +583,7 @@ sub configure_row {
     }
     
     my $row = $self->{'rows'}->{$self->{'part'}}->[-1];
-    foreach my $config_item (keys %$config) {
+    foreach my $config_item (keys(%$config)) {
 	$row->{$config_item} = $config->{$config_item};
     }
 }
@@ -996,7 +996,7 @@ sub generate {
 
 	my $specified_width = 0.0;
 	my $specified_cols   = 0;
-	foreach my $col (keys %$colwidths) {
+	foreach my $col (keys(%$colwidths)) {
 	    $specified_width = $specified_width + $colwidths->{$col};
 	    $specified_cols++;
 	}
@@ -1026,7 +1026,7 @@ sub generate {
 	    $default_width = ($tablewidth/$unspecified_cols);                     # 'fair' default width.
 	    my $width_remaining = $tablewidth - $default_width*$unspecified_cols; # What's left for the specified cols.
 	    my $reduction       = $tablewidth/$width_remaining;                    # Reduction fraction for specified cols
-	    foreach my $col (keys %$colwidths) {
+	    foreach my $col (keys(%$colwidths)) {
 		$colwidths->{$col} = $colwidths->{$col}/$reduction;
 	    }
 	    
