@@ -2,7 +2,7 @@
 #
 # Page flip handler
 #
-# $Id: lonpageflip.pm,v 1.80.8.12 2021/03/04 01:33:43 raeburn Exp $
+# $Id: lonpageflip.pm,v 1.80.8.13 2021/12/14 21:34:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -231,9 +231,13 @@ sub first_accessible_resource {
     if (tie(%hash,'GDBM_File',$env{'request.course.fn'}.'.db',
 	    &GDBM_READER(),0640)) {
 	$furl=$hash{'first_url'};
-	my %args;
-	my ($url,$args) = split(/\?/,$furl);
-	foreach my $pair (split(/\&/,$args)) {
+	my (%args,$url,$argstr);
+	if ($furl =~ m{^/enc/}) {
+	    ($url,$argstr) = split(/\?/,&Apache::lonenc::unencrypted($furl));
+	} else {
+	    ($url,$argstr) = split(/\?/,$furl);
+	}
+	foreach my $pair (split(/\&/,$argstr)) {
 	    my ($name,$value) = split(/=/,$pair);
 	    $args{&unescape($name)} = &unescape($value);
 	}
@@ -241,13 +245,17 @@ sub first_accessible_resource {
 # Wow, we cannot see this ... move forward to the next one that we can see
 	    my ($newrid,$newmap)=&move($hash{'first_rid'},$hash{'first_mapurl'},'forward');
 # Build the new URL
-	    my ($newmapid,$newresid)=split(/\./,$newrid);
-	    my $symb=&Apache::lonnet::encode_symb($newmap,$newresid,$hash{'src_'.$newrid});
-	    $furl=&add_get_param($hash{'src_'.$newrid},{ 'symb' => $symb });
-	    if ($hash{'encrypted_'.$newrid}) {
-		$furl=&Apache::lonenc::encrypted($furl);
+            if ($newrid eq '') {
+                $furl = '/adm/navmaps';
+            } else {
+	        my ($newmapid,$newresid)=split(/\./,$newrid);
+	        my $symb=&Apache::lonnet::encode_symb($newmap,$newresid,$hash{'src_'.$newrid});
+	        $furl=&add_get_param($hash{'src_'.$newrid},{ 'symb' => $symb });
+	        if ($hash{'encrypted_'.$newrid}) {
+		    $furl=&Apache::lonenc::encrypted($furl);
+	        }
 	    }
-	}
+        }
 	untie(%hash);
 	return $furl;
     } else {
@@ -256,7 +264,7 @@ sub first_accessible_resource {
 }
 
 sub check_http_req {
-    my ($srcref) = @_;
+    my ($srcref,$hostname) = @_;
     return unless (ref($srcref) eq 'SCALAR');
     my $usehttp;
     if ($env{'request.course.id'}) {
@@ -265,13 +273,15 @@ sub check_http_req {
         if (($$srcref =~ m{^\Q/public/$cdom/$cnum/syllabus\E($|\?)}) &&
             ($ENV{'SERVER_PORT'} == 443) &&
             ($env{'course.'.$env{'request.course.id'}.'.externalsyllabus'} =~ m{^http://})) {
-            unless (&Apache::lonnet::uses_sts()) {
+            unless ((&Apache::lonnet::uses_sts()) ||
+                    (&Apache::lonnet::waf_allssl($hostname))) {
                 $$srcref .= (($$srcref =~/\?/)? '&':'?') . 'usehttp=1';
                 $usehttp = 1;
             }
         } elsif (($$srcref =~ m{^\Q/adm/wrapper/ext/\E(?!https:)}) &&
                  ($ENV{'SERVER_PORT'} == 443)) {
-            unless (&Apache::lonnet::uses_sts()) {
+            unless ((&Apache::lonnet::uses_sts()) ||
+                    (&Apache::lonnet::waf_allssl($hostname))) {
                 my ($url,$anchor) = ($$srcref =~ /^([^\#]+)(?:|(\#[^\#]+))$/);
                 $$srcref = $url . (($$srcref =~/\?/)? '&':'?') . 'usehttp=1' .$anchor;
                 $usehttp = 1;
@@ -391,7 +401,7 @@ sub handler {
       }
       if ($direction eq 'firstres') {
 	  my $furl=&first_accessible_resource();
-          my $usehttp = &check_http_req(\$furl);
+          my $usehttp = &check_http_req(\$furl,$hostname);
           if (($usehttp) && ($hostname ne '')) {
               $furl='http://'.$hostname.$furl;
           } else {
@@ -417,7 +427,7 @@ sub handler {
 	    $id=$hash{'map_pc_'.&Apache::lonnet::clutter($murl)}.'.'.$id;
 	    $newloc=$hash{'src_'.$id};
 	    if ($newloc) {
-                $usehttp = &check_http_req(\$newloc);
+                $usehttp = &check_http_req(\$newloc,$hostname);
                 if ($hash{'encrypted_'.$id}) {
                     $newloc=&Apache::lonenc::encrypted($newloc);
                 }
@@ -556,7 +566,7 @@ sub handler {
 # ------------------------------------- Check for and display critical messages
                   my ($redirect, $url) = &Apache::loncommon::critical_redirect(300);
                   unless ($redirect) {
-                      my $usehttp = &check_http_req(\$redirecturl);
+                      my $usehttp = &check_http_req(\$redirecturl,$hostname);
                       if (($usehttp) && ($hostname ne '')) {
                           $url='http://'.$hostname.$redirecturl;
                       } else {
@@ -617,7 +627,7 @@ $lt{'pick'}:
 ENDSTART
                      foreach my $id (@possibilities) {
                         my $src = $multichoicehash{'src_'.$id};
-                        my $usehttp = &check_http_req(\$src);
+                        my $usehttp = &check_http_req(\$src,$hostname);
                         if (($usehttp) && ($hostname ne '')) {
                             $src = 'http://'.$hostname.$src;
                         }
