@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Wrapper for external and binary files as standalone resources
 #
-# $Id: lonwrapper.pm,v 1.49.2.11 2021/12/15 00:41:48 raeburn Exp $
+# $Id: lonwrapper.pm,v 1.49.2.12 2024/07/04 02:30:39 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -73,7 +73,7 @@ sub wrapper {
         }
     }
 
-    my $noiframe = &Apache::loncommon::modal_link($url.$anchor,$lt{'show'},500,400);
+    my $noiframe = &Apache::loncommon::modal_link(&HTML::Entities::encode($url.$anchor,'&<>"\''),$lt{'show'},500,400);
     my $args = {'bgcolor' => '#FFFFFF'};
     if ($forcereg) {
         $args->{'force_register'} = $forcereg;
